@@ -17,10 +17,13 @@ impl<'s> From<&'s str> for Text<'s> {
 }
 
 impl<'s> Text<'s> {
+    pub fn from_str(
+        s: &'s str,
+        options: Options,
+    ) -> Self {
+        crate::parser::parse_lines(s.lines(), options)
+    }
     /// Parse a text from markdown lines.
-    ///
-    /// To build a text with parsing options, prefer the
-    /// `termimad::parse_text` function
     pub fn from_md_lines<I>(md_lines: I) -> Self
     where
         I: Iterator<Item = &'s str>,
@@ -32,3 +35,25 @@ impl<'s> Text<'s> {
         Self { lines }
     }
 }
+
+#[test]
+fn test_keep_code_fences() {
+    let md = r"# Heading
+Simple text.
+```rust
+    let a = 10;
+    let b = 20;
+```
+";
+
+    // not keeping code fences
+    let text = Text::from_str(md, Options::default().keep_code_fences(false));
+    assert_eq!(text.lines.len(), 4);
+
+    // keeping code fences
+    let text = Text::from_str(md, Options::default().keep_code_fences(true));
+    dbg!(&text);
+    assert_eq!(text.lines.len(), 6);
+    let lang = text.lines[2].code_fence_lang().unwrap();
+    assert_eq!(lang, "rust");
+}
