@@ -186,7 +186,7 @@ impl<'s> From<&'s str> for TextTemplate<'s> {
                 _ => {
                     text.lines.push(line);
                 }
-            };
+            }
         }
         TextTemplate {
             text,
@@ -202,7 +202,7 @@ impl<'s> TextTemplate<'s> {
         TextTemplateExpander::from(self)
     }
 
-    /// if the line `line_idx` is part of a template, return this
+    /// if the line `line_idx` is part of a sub template, return this
     /// template's index. Return None if it's not part of a template.
     ///
     /// This might be optimized by an internal vec in the future (or
@@ -505,7 +505,7 @@ impl<'s, 'b> TextTemplateExpander<'s, 'b> {
             for idx in start..end {
                 self.lines_to_exclude[idx] = true;
             }
-            for sub_expansion in self.sub_expansions.iter() {
+            for sub_expansion in &self.sub_expansions {
                 if sub_expansion.name != sub_template.name {
                     continue;
                 }
